//	NPBMapping.h - Simple struct which holds the relevant data for a
//				   mapping between the joystick's controls and the
//				   plugin's parameters.
//	--------------------------------------------------------------------------
//	This file is part of 'Niall's Pedal Board', a simple ASIO VST host.
//	Copyright (C) 2004-2005  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------
//	
//	You can e-mail me at niallmoody@yahoo.co.uk if you want.
//	
//	--------------------------------------------------------------------------

#ifndef NPBMAPPING_H_
#define NPBMAPPING_H_

#ifndef JOYSTICK_H_
#include "Joystick.h"
#endif

///	This structure holds all the data for a joystick->parameter (or MIDI) mapping.
/*!
	Basically, it represents the data for a particular joystick event (button
	pressed, axis changed), and what that event should be mapped to (plugin
	parameter or MIDI message), as well as the minimum and maximum values
	which the value from the joystick should be restricted to.
 */
typedef struct
{
	///	If there's more than one joystick, this'll differentiate between them.
	int JoyIndex;
	///	e.g. button.
	JoystickEventType JoyControl;
	///	e.g. which button
	int Index;
	float MinVal;
	float MaxVal;
	///	The parameter of the plugin this mapping affects.
	long PluginParameter;

	/// true=parameter, false=MIDI
	bool parameterType;
	///	0-127=MIDI CC, 129=Velocity
	/*!
		To generate a MIDI noteOn, set the noteval, then generate a velocity
		message (> 0).  Any velocity message afterwards with a velocity of
		0 will generate the appropriate noteOff message.
	 */
	int MIDI;
	///	MIDI NoteOn/Off messages are sent when the joystick sends a velocity message.
	/*!
		This parameter is used to associate a particular MIDINote with the
		velocity message (the two are combined to create the NoteOn/NoteOff
		messages).
	 */
	char MIDINote;
} NPBMapping;

#endif
