//	NPBOptionsDialog.h - dialog for selecting sound cards etc.
//	--------------------------------------------------------------------------
//	This file is part of 'Niall's Pedal Board', a simple ASIO VST host.
//	Copyright (C) 2004-2005  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------
//	
//	You can e-mail me at niallmoody@yahoo.co.uk if you want.
//	
//	--------------------------------------------------------------------------

#ifndef NPBOPTIONSDIALOG_H_
#define NPBOPTIONSDIALOG_H_

#ifndef NPBWINDOW_H_
#include "NPBWindow.h"
#endif

#include <juce.h>

///	Dialog allowing the user to select a soundcard.
class NPBOptionsDialog : public DialogWindow
{
  public:
	///	Constructor.
	/*!
		\param col The colour of the window's background.
	 */
	NPBOptionsDialog(Colour col);
	///	Destructor.
	~NPBOptionsDialog();
};

///	The contents of NPBOptionsDialog.
/*!
	Inherits from SimpleListBoxModel because we use a list box to list all the
	soundcard inputs/outputs.
 */
class NPBOptionsContent : public Component,
								 ActionListener,
								 SimpleListBoxModel
{
  public:
	///	Constructor.
	/*!
		\param parent We need this to inform the window about any changes
		we've made.
		\param col The colour of the window's background.
	 */
	NPBOptionsContent(NPBWindow *parent, Colour col);
	///	Destructor.
	~NPBOptionsContent();

	///	Fills in the background with backColour.
	void paint(Graphics& g);
	///	So we know when the user's pressed OK, etc.
	void actionListenerCallback(const String& m);

	///	To position all the Components correctly.
	void resized();

	///	One of the methods you have to implement if you inherit from SimpleListBoxModel.
	int getNumRows() {return (Strings2.size()+Strings3.size());};
	//int getNumRows() {return 24;};
	///	Used to draw the contents of the list box.
	void paintListBoxItem(int rowNumber, Graphics &g, int width, int height, bool rowIsSelected);
  private:
	///	Helper method to get the names of the I/O channels for the selected device.
	/*!
		We have to create an ASIOAudioIODevice to do this, which is why it's
		in a separate method.
	 */
	void DeviceChosen();

	NPBWindow *Parent;

	ComboBox *Soundcards;
	SimpleListBox *IOs;
	TextButton *OK;
	TextButton *ControlPanel;
	TextButton *Cancel;
	ToggleButton *directMode;

	StringArray *Strings1;
	StringArray Strings2;
	StringArray Strings3;

	Colour backColour;
};

#endif
